pub struct Input { /* private fields */ }Expand description
A decorated Tensor passed to TensorBuilder::set_inputs.
Use new to create an immutable input, or new_mut to create a modifiable one.
See also TensorBuilder.
Implementations
Sourceimpl<'graph> Input
impl<'graph> Input
Sourcepub fn new<F: Float>(val: &Tensor<'graph, F>) -> Input
pub fn new<F: Float>(val: &Tensor<'graph, F>) -> Input
Instantiates a new immutable Input object.
Run-time value of val is passed as an ndarray::ArrayView in Op::compute.
Sourcepub fn new_mut<F: Float>(val: &Tensor<'graph, F>) -> Input
pub fn new_mut<F: Float>(val: &Tensor<'graph, F>) -> Input
Instantiates a new mutable Input object.
Run-time value of val is passed as an ArrayViewMut in Op::compute.
pub fn as_tensor<F: Float>(&self, graph: &'graph Graph<F>) -> Tensor<'graph, F>